@@ -108,20 +108,20 @@ package org.evolvis.tartools.csvfile;
  * @author Fabrizio Fazzino
  */
 public abstract class CSVFile {
-    // helper string constants
-    public static final String CR = "" + (char) 0x0D;
-    public static final String LF = "" + (char) 0x0A;
-    public static final String CRLF = CR + LF;
+    // helper string constants, tested for precise byte values
+    public static final String CR = "\r";
+    public static final String LF = "\n";
+    public static final String CRLF = "\r\n";
 
     /**
      * The default char used as field separator.
      */
-    protected static final char DEFAULT_FIELD_SEPARATOR = ',';
+    public static final char DEFAULT_FIELD_SEPARATOR = ',';
 
     /**
      * The default char used as text qualifier.
      */
-    protected static final char DEFAULT_TEXT_QUALIFIER = '"';
+    public static final char DEFAULT_TEXT_QUALIFIER = '"';
 
     /**
      * The current char used as field separator.
